@@ -17,12 +17,13 @@
 
 static void explain(void)
 {
-	fprintf(stderr, "Usage: ... hhf [ limit PACKETS ] [ quantum BYTES]\n");
-	fprintf(stderr, "               [ hh_limit NUMBER ]\n");
-	fprintf(stderr, "               [ reset_timeout TIME ]\n");
-	fprintf(stderr, "               [ admit_bytes BYTES ]\n");
-	fprintf(stderr, "               [ evict_timeout TIME ]\n");
-	fprintf(stderr, "               [ non_hh_weight NUMBER ]\n");
+	fprintf(stderr,
+		"Usage: ... hhf	[ limit PACKETS ] [ quantum BYTES]\n"
+		"		[ hh_limit NUMBER ]\n"
+		"		[ reset_timeout TIME ]\n"
+		"		[ admit_bytes BYTES ]\n"
+		"		[ evict_timeout TIME ]\n"
+		"		[ non_hh_weight NUMBER ]\n");
 }
 
 static int hhf_parse_opt(struct qdisc_util *qu, int argc, char **argv,
